# Security Policy

## Supported Versions

We release patches for security vulnerabilities for some project version. Check below which are these version::

| Version | Supported          |
| ------- | ------------------ |
| 0.2.x   | :white_check_mark: |
| 0.1.x   | :x:                |

## Reporting a Vulnerability

Please report (suspected) security vulnerabilities to [issues section](https://github.com/lucasrodes/whatstk/issues). We will analyze it and if the issue is confirmed, we will release a patch as soon as possible.


